<?php 

namespace FasterYoutube\Block;

/**
 * analytical data store
*/
class Fasteryoutube_Block 
{
	/**
     * [$_instance]
     * @var null
     */
    private static $_instance = null;

    /**
     * [instance] Initializes a singleton instance
     * @return [Actions]
     */
    public static function instance() {
        if ( is_null( self::$_instance ) ) {
            self::$_instance = new self();
            self::$_instance->define_constants();
        }
        return self::$_instance;
    }

	/**
	 * The Constructor.
	*/
	public function __construct() {
		add_action( 'init', [ $this, 'init' ] );
		add_action( 'enqueue_block_assets', [ $this, 'block_assets' ] );
	}

	public function init(){

		// Return early if this function does not exist.
		if ( ! function_exists( 'register_block_type' ) ) {
			return;
		}
		$this->register_block();
	}

	/**
     * Define constant if not already set
     *
     * @param  string $name
     * @param  string|bool $value
     * @return type
     */
    private function define( $name, $value ) {
        if ( ! defined( $name ) ) {
            define( $name, $value );
        }
    }

	/**
	 * Block assets.
	 */
	public function block_assets() {

		$dependencies = require_once( HTYOUTUBEMBED_BLOCK_PATH . '/build/faster-youtube.asset.php' );
		wp_enqueue_script(
		    'ht-youtub-embed-blocks',
		    HTYOUTUBEMBED_BLOCK_URL . '/build/faster-youtube.js',
		    $dependencies['dependencies'],
		    $dependencies['version'],
		    true
		);

		wp_enqueue_script(
		    'ht-youtube-embed-js',
		    HTYOUTUBEMBED_PL_URL . 'assets/js/LiteYTEmbed.js',
		    $dependencies['dependencies'],
		    $dependencies['version'],
		    true
		);

		wp_enqueue_style(
		    'ht-youtube-embed-css',
		    HTYOUTUBEMBED_PL_URL . 'assets/css/ht-youtube-embed.css',
		    array(),
		    $dependencies['version']
		);
	}

	private function register_block(){

		ob_start();
		include HTYOUTUBEMBED_BLOCK_PATH . '/src/blocks/fasteryoutube/block.json';
		$metadata = json_decode( ob_get_clean(), true );
		
		register_block_type(
			$metadata['name'], 
			array(
				'render_callback' => [ $this, 'faster_youtube_embed_block_callback' ],
				'attributes'  => $metadata['attributes'],
			)
		);
	}

	/**
	 * Define the required plugin constants
	 *
	 * @return void
	 */
	public function define_constants() {
		$this->define( 'HTYOUTUBEMBED_BLOCK_FILE', __FILE__ );
		$this->define( 'HTYOUTUBEMBED_BLOCK_PATH', __DIR__ );
		$this->define( 'HTYOUTUBEMBED_BLOCK_URL', plugins_url( '', HTYOUTUBEMBED_BLOCK_FILE ) );
	}

	public function faster_youtube_embed_block_callback($attributes){
		
		$y_params = array(
			"controls" 				=> ($attributes['htYoutubeController'] == 'yes') ? '1': '0',
			"start" 				=> $attributes['htYoutubevideoStartTime'],
			"end" 					=> $attributes['htYoutubevideoEndTime'],
			"thumbnail" 			=> (isset($attributes['youtubeThumbnailImage'] ) && !empty($attributes['youtubeThumbnailImage'] )) ? $attributes['youtubeThumbnailImage']['img_url'] : '',
			"thumbnailresolution" 	=> $attributes['thumbnailresolution'],
			'className'				=> (isset( $attributes['className'] )) ? $attributes['className'] : '',
		);
		$_youtubeId = $attributes['htYoutubeId'];
		$ht_youtube = ht_youtube_embed_shortcode($y_params, $_youtubeId);
		return $ht_youtube;
	}
}

Fasteryoutube_Block::instance();