<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}
class HTFASTER_YOUTUBE_EMBED {
    const MINIMUM_PHP_VERSION = '7.0';
    
    private static $_instance = null;

    public static function instance() {
        if ( is_null( self::$_instance ) ) {
            self::$_instance = new self();
        }
        return self::$_instance;
    }

    public function __construct() {
        add_action( 'init', [ $this, 'i18n' ] );
        add_action( 'plugins_loaded', [ $this, 'init' ] );
        add_action( 'admin_enqueue_scripts', [ $this, 'admin_enqueue_scripts' ] );
        add_action( 'wp_enqueue_scripts', [ $this,'register_assets'] );
    }

    public function i18n() {
        load_plugin_textdomain( 'ht-youtube-embed', false, dirname( plugin_basename( HTYOUTUBEMBED_PL_ROOT ) ) . '/languages/' );
    }
    
    public function init() {
        
        // Check for required PHP version
        if ( version_compare( PHP_VERSION, self::MINIMUM_PHP_VERSION, '<' ) ) {
            add_action( 'admin_notices', [ $this, 'admin_notice_minimum_php_version' ] );
            return;
        }

        // Plugins Required File
        $this->includes();

        // Add Plugin actions
        if(did_action( 'elementor/loaded' )){
            add_action( 'elementor/widgets/widgets_registered', [ $this, 'init_widgets' ] );
        }
    }

    public function admin_notice_minimum_php_version() {

        if ( isset( $_GET['activate'] ) ) unset( $_GET['activate'] );
        $message = sprintf(
            /* translators: 1: Plugin name 2: PHP 3: Required PHP version */
            esc_html__( '"%1$s" requires "%2$s" version %3$s or greater.', 'ht-youtube-embed' ),
            '<strong>' . esc_html__( 'Faster YouTube Embed', 'ht-youtube-embed' ) . '</strong>',
            '<strong>' . esc_html__( 'PHP', 'ht-youtube-embed' ) . '</strong>',
             self::MINIMUM_PHP_VERSION
        );
        printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );
    }

     /**
     * Enqueue scripts and styles
     */
    function admin_enqueue_scripts($hook) {
        if('widgets.php' === $hook){
        wp_enqueue_media();
        wp_enqueue_script( 'jquery' );
        wp_enqueue_script( 'youtube-embed-admin', HTYOUTUBEMBED_PL_URL . 'assets/js/admin-min.js',array(), HTYOUTUBEMBED_VERSION, TRUE );
        }
    }

    /*
    * Assest Management
    */
    public function register_assets(){
        wp_register_style('ht-youtube-embed-css', HTYOUTUBEMBED_PL_URL . 'assets/css/ht-youtube-embed.css', '', HTYOUTUBEMBED_VERSION );
        wp_register_script( 'ht-youtube-embed-js', HTYOUTUBEMBED_PL_URL . 'assets/js/LiteYTEmbed.js',array('jquery'), HTYOUTUBEMBED_VERSION, TRUE );
    }

    public function includes() {
        require_once HTYOUTUBEMBED_PL_PATH.'include/default_widgets.php';
        require_once HTYOUTUBEMBED_PL_PATH.'include/youtube_shortcode.php';
        require_once HTYOUTUBEMBED_PL_PATH. 'block/block-init.php';
    }

    public function init_widgets() {
       // Include Widget files
       include( HTYOUTUBEMBED_PL_INCLUDE.'/elementor_widgets.php' );
       // Register widget
       \Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Elementor\HTFASTER_YOUTUBE_EMBED_ELEMENTOR_WIDGET() );
    }
}