<?php

if ( !class_exists('HTFASTER_YOUTUBE_EMBED_DEFAULT_WIDGET') ) {
    class HTFASTER_YOUTUBE_EMBED_DEFAULT_WIDGET extends WP_Widget{

        function __construct(){
            $widget_options = array(
                'description'                   => esc_html__('Faster YouTube Embed', 'ht-youtube-embed'), 
                'customize_selective_refresh'   => true,
            );

            parent:: __construct(
                'HTFASTER_YOUTUBE_EMBED_DEFAULT_WIDGET', 
                esc_html__( 'Faster YouTube Embed', 'ht-youtube-embed') );
        }
        /**
         * Front-end display of widget.
         *
         * @see WP_Widget::widget()
         *
         * @param array $args     Widget arguments.
         * @param array $instance Saved values from database.
         */
        public function widget($args, $instance){ 
            $title                  = isset( $instance['title'] ) ? $instance['title'] : ''; 
            $youtubeID              = isset( $instance['youtubeID'] ) ? $instance['youtubeID'] : ''; 
            $controls               = isset( $instance['controls'] ) ? $instance['controls'] : ''; 
            $start                  = isset( $instance['start'] ) ? $instance['start'] : ''; 
            $end                    = isset( $instance['end'] ) ? $instance['end'] : ''; 
            $thumbnail              = isset( $instance['thumbnail'] ) ? $instance['thumbnail'] : ''; 
            $thumbnailresolution    = isset( $instance['thumbnailresolution'] ) ? $instance['thumbnailresolution'] : ''; 

            // Render Html
            echo wp_kses_post( $args['before_widget'] );
                if ( !empty( $title ) ) { 
                    echo wp_kses_post($args['before_title']) . esc_html__( $title,'ht-youtube-embed' ) . wp_kses_post($args['after_title']); 
                }
                ?>
                <div class="htinsta-widgets">
                    <?php  echo do_shortcode( sprintf( '[htyoutube controls="%s" start="%s" end="%s" thumbnail="%s" thumbnailresolution="%s" ]%s[/htyoutube]', $controls, $start, $end, $thumbnail, $thumbnailresolution, $youtubeID) );
                    ?>
                </div>
            <?php echo wp_kses_post($args['after_widget']); 
            
        }

        /**
         * Sanitize widget form values as they are saved.
         *
         * @see WP_Widget::update()
         *
         * @param array $new_instance Values just sent to be saved.
         * @param array $old_instance Previously saved values from database.
         *
         * @return array Updated safe values to be saved.
         */

        public function update( $new_instance, $old_instance ) {
            $instance = $old_instance;  
            $instance['title']                  =  strip_tags($new_instance['title']);
            $instance['youtubeID']              =  strip_tags($new_instance['youtubeID']);
            $instance['controls']               =  strip_tags($new_instance['controls']);
            $instance['start']                  =  strip_tags($new_instance['start']);
            $instance['end']                    =  strip_tags($new_instance['end']);
            $instance['thumbnail']              =  strip_tags($new_instance['thumbnail']);
            $instance['thumbnailresolution']    =  strip_tags($new_instance['thumbnailresolution']);
            
            return $instance;
        }

        /**
         * Back-end widget form.
         *
         * @see WP_Widget::form()
         *
         * @param array $instance Previously saved values from database.
         */

        public function form( $instance ){ 

            $array_default = array(

                'title'                 => esc_html__('Faster YouTube Embed','ht-youtube-embed'),
                'youtubeID'             => '',
                'controls'              => '1',
                'start'                 => '',
                'end'                   => '',
                'thumbnail'             => '',
                'thumbnailresolution'   => 'recommended',
            );
            $instance = wp_parse_args( (array) $instance, $array_default );
            ?>

            <p>
                <label for="<?php echo esc_attr($this->get_field_id('title')); ?>"><?php echo esc_html__('Enter Your Title:', 'ht-youtube-embed'); ?> </label>
                <input class="widefat" id="<?php echo esc_attr($this->get_field_id('title')); ?>" name="<?php echo esc_attr($this->get_field_name('title')); ?>" type="text" value="<?php echo esc_attr($instance['title']); ?>" placeholder="<?php echo esc_attr_x( 'Please enter your title here.', 'placeholder', 'ht-youtube-embed' ); ?>" />
            </p>

            <p>
                <label for="<?php echo esc_attr($this->get_field_id('youtubeID')); ?>"><?php echo esc_html__('YouTube URL or YouTube Video ID:', 'ht-youtube-embed'); ?> </label>
                <input class="widefat" id="<?php echo esc_attr($this->get_field_id('youtubeID')); ?>" name="<?php echo esc_attr($this->get_field_name('youtubeID')); ?>" type="text" value="<?php echo esc_attr($instance['youtubeID']); ?>" placeholder="<?php echo esc_attr_x( 'Please enter your YouTube URL or YouTube Video ID', 'placeholder', 'ht-youtube-embed' ); ?>"/>
            </p>

            <p>
                <label for="<?php echo esc_attr( $this->get_field_id('controls')); ?>"><?php echo esc_html__('Player Controller:', 'ht-youtube-embed'); ?> </label>
                <select class="widefat" id="<?php echo esc_attr( $this->get_field_id('controls')); ?>" name="<?php echo esc_attr($this->get_field_name('controls')); ?>" value="<?php echo esc_attr($instance['controls']); ?>" >
                  <option  <?php selected( $instance['controls'], '1' ); ?> value="1"><?php echo esc_html__('Yes', 'ht-youtube-embed'); ?></option>
                  <option <?php selected( $instance['controls'], '0' ); ?> value="0"><?php echo esc_html__('No', 'ht-youtube-embed'); ?></option>
                </select>
            </p>

            <p>
                <label for="<?php echo esc_attr($this->get_field_id('start')); ?>"><?php echo esc_html__('Video Start Time :', 'ht-youtube-embed'); ?> </label>
                <input class="widefat" id="<?php echo esc_attr($this->get_field_id('start')); ?>" name="<?php echo esc_attr($this->get_field_name('start')); ?>" type="number" value="<?php echo esc_attr($instance['start']); ?>" placeholder="<?php echo esc_attr_x( 'Specify a start time (in seconds)', 'placeholder', 'ht-youtube-embed' ); ?>"/>
            </p>

            <p>
                <label for="<?php echo esc_attr($this->get_field_id('end')); ?>"><?php echo esc_html__('Video End Time :', 'ht-youtube-embed'); ?> </label>
                <input class="widefat" id="<?php echo esc_attr($this->get_field_id('end')); ?>" name="<?php echo esc_attr($this->get_field_name('end')); ?>" type="number" value="<?php echo esc_attr($instance['end']); ?>" placeholder="<?php echo esc_attr_x( 'Specify a end time (in seconds)', 'placeholder', 'ht-youtube-embed' ); ?>"/>
            </p>

            <p>
                <label for="<?php echo esc_attr($this->get_field_id('thumbnail')); ?>"><?php echo esc_html__('YouTube Thumbnail Image:', 'ht-youtube-embed'); ?> </label>
                <input class="widefat" id="<?php echo esc_attr($this->get_field_id('thumbnail')); ?>" name="<?php echo esc_attr($this->get_field_name('thumbnail')); ?>" type="text" value="<?php echo esc_attr($instance['thumbnail']); ?>" placeholder="<?php echo esc_attr_x( 'Thumbnail Image Image URL', 'placeholder', 'ht-youtube-embed' ); ?>"/>
                    <input type="button" class="button button-primary htyoutube-browse widefat" value="<?php echo esc_attr__( 'Choose YouTube Thumbnail Image', 'ht-youtube-embed' ); ?>">
                    
            </p>

            <p>
                <label for="<?php echo esc_attr( $this->get_field_id('thumbnailresolution')); ?>"><?php echo esc_html__('Thumbnail Resolution:', 'ht-youtube-embed'); ?> </label>
                <select class="widefat" id="<?php echo esc_attr( $this->get_field_id('thumbnailresolution')); ?>" name="<?php echo esc_attr($this->get_field_name('thumbnailresolution')); ?>" value="<?php echo esc_attr($instance['thumbnailresolution']); ?>" >
                  <option  <?php selected( $instance['thumbnailresolution'], 'lowest' ); ?> value="lowest"><?php echo esc_html__('Lowest Quality Dimensions: 120px × 90px', 'ht-youtube-embed'); ?></option>
                  <option  <?php selected( $instance['thumbnailresolution'], 'medium' ); ?> value="medium"><?php echo esc_html__('Medium Quality Dimensions: 320px × 180px', 'ht-youtube-embed'); ?></option>
                  <option  <?php selected( $instance['thumbnailresolution'], 'high' ); ?> value="high"><?php echo esc_html__('High Quality Dimensions: 480px × 360px', 'ht-youtube-embed'); ?></option>
                  <option  <?php selected( $instance['thumbnailresolution'], 'standard' ); ?> value="standard"><?php echo esc_html__('Standard Quality Dimensions: 640px × 480px', 'ht-youtube-embed'); ?></option>
                  <option  <?php selected( $instance['thumbnailresolution'], 'recommended' ); ?> value="recommended"><?php echo esc_html__('Recommended Thumbnail Dimension for SEO: 1280px × 720px', 'ht-youtube-embed'); ?></option>
                  
                </select>
            </p>

        <?php }
    } // end extends class
} // end exists class

// Register Author information widget.
function HTFASTER_YOUTUBE_EMBED_DEFAULT_WIDGET() {
    register_widget( 'HTFASTER_YOUTUBE_EMBED_DEFAULT_WIDGET' );
}
add_action( 'widgets_init', 'HTFASTER_YOUTUBE_EMBED_DEFAULT_WIDGET' );