<?php
namespace Elementor;

if( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class HTFASTER_YOUTUBE_EMBED_ELEMENTOR_WIDGET extends Widget_Base {

    public function get_name() {
        return 'htyoutube-addons';
    }
    
    public function get_title() {
        return esc_html__( 'Faster YouTube Embed', 'ht-youtube-embed' );
    }

    public function get_icon() {
        return 'eicon-youtube';
    }

    public function get_categories() {
        return [ 'general' ];
    }
    protected function register_controls() {
       

        $this->start_controls_section(
                'ht_youtube_alignment',
                [
                    'label' => esc_html__( 'Faster YouTube Embed', 'ht-youtube-embed' ),
                    'tab' => Controls_Manager::TAB_CONTENT,
                ]
            );

            $this->add_control(
                'youtube_ID',
                [
                    'label' => esc_html__( 'YouTube URL or YouTube ID:', 'ht-youtube-embed' ),
                    'type' => Controls_Manager::TEXT,
				    'rows' => 2,
                    'placeholder' => esc_html__( 'Please Enter your Video URL OR Video ID.', 'ht-youtube-embed' ),
                    'label_block' => true,
                ]
            );

            $this->add_control(
                'ht_youtube_title',
                    [
                        'label' => esc_html__( 'YouTube Player Configuration:', 'ht-youtube-embed' ),
                        'type' => Controls_Manager::HEADING,
                        'separator' => 'before',
                    ]
            );

            $this->add_control(
                'ht_youtube_divider',
                    [
                        'type' => Controls_Manager::DIVIDER,
                    ]
             );

            $this->add_control(
                'youtube_control',
                [
                    'label' => esc_html__( 'Player Controller:', 'ht-youtube-embed' ),
                    'type' => Controls_Manager::SWITCHER,
                    'label_on' => esc_html__( 'On', 'ht-youtube-embed' ),
                    'label_off' => esc_html__( 'Off', 'ht-youtube-embed' ),
                    'return_value' => '1',
                    'default' => '1',
                ]
            );

            $this->add_control(
                'youtube_start_time',
                [
                    'label' => esc_html__( 'Video Start Time ', 'ht-youtube-embed' ),
                    'type' => Controls_Manager::NUMBER,
                    'description' => esc_html__( 'Specify a start time (in seconds)', 'ht-youtube-embed' )
                ]
            );

            $this->add_control(
                'youtube_end_time',
                [
                    'label' => esc_html__( 'Video End Time', 'ht-youtube-embed' ),
                    'type' => Controls_Manager::NUMBER,
                    'description' => esc_html__( 'Specify a End time (in seconds)', 'ht-youtube-embed' )
                ]
            );

            $this->add_control(
                'youtube_thumbnail',
                    [
                        'label' => esc_html__( 'Choose Thumbnail Image', 'ht-youtube-embed' ),
                        'type' => Controls_Manager::MEDIA,
                    ]
            );

            $this->add_control(
                'thumbnailresolution',
                [
                    'label' => __( 'Select YouTube Thumbnail Resolution:', 'ht-youtube-embed' ),
                    'type' => \Elementor\Controls_Manager::SELECT,
                    'default' => 'recommended',
                    'label_block' => true,
                    'options' => [
                        'lowest'  => __( 'Lowest Quality Dimensions: 120px × 90px', 'ht-youtube-embed' ),
                        'medium' => __( 'Medium Quality Dimensions: 320px × 180px', 'ht-youtube-embed' ),
                        'high' => __( 'High Quality Dimensions: 480px × 360px', 'ht-youtube-embed' ),
                        'standard' => __( 'Standard Quality Dimensions: 640px × 480px', 'ht-youtube-embed' ),
                        'recommended' => __( 'Recommended Thumbnail Dimension for SEO: 1280px × 720px', 'ht-youtube-embed' ),
                    ],
                ]
            );

        $this->end_controls_section();
    }

    protected function render( $instance = [] ) {
        $settings = $this->get_settings_for_display();
        if(empty($settings['youtube_control'])){
            $settings['youtube_control'] = 0;
        }

        $video_attributes = [
            'controls' => $settings['youtube_control'],
            'start' => $settings['youtube_start_time'],
            'end' => $settings['youtube_end_time'],
            'thumbnail' => $settings['youtube_thumbnail']['url'],
            'thumbnailresolution' => $settings['thumbnailresolution'],

        ];
        
        $this->add_render_attribute( 'shortcode', $video_attributes );
        echo do_shortcode( sprintf( '[htyoutube %s]%s[/htyoutube]', $this->get_render_attribute_string( 'shortcode' ), $settings['youtube_ID'] ) );
    }
}

Plugin::instance()->widgets_manager->register_widget_type( new HTFASTER_YOUTUBE_EMBED_ELEMENTOR_WIDGET() );